pecos.error\_models.old
=======================

.. automodule:: pecos.error_models.old



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.error_models.old.depolar_gen
   pecos.error_models.old.gatewise_gen
   pecos.error_models.old.xerror_gen
   pecos.error_models.old.xzerror_gen
   pecos.error_models.old.zerror_gen
